@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2016-12-11'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2016-12-15'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 use 5.010001;
 use strict;
@@ -951,7 +951,7 @@ sub get_args_from_argv {
         local $SIG{__WARN__} = sub{} if !$strict;
         my $old_go_conf = Getopt::Long::Configure(
             $strict ? "no_pass_through" : "pass_through",
-            "no_ignore_case", "permute", "bundling", "no_getopt_compat", "gnu_compat");
+            "no_ignore_case", "permute", "no_getopt_compat", "gnu_compat", "bundling");
         my $res = Getopt::Long::GetOptionsFromArray($argv, %$go_spec);
         Getopt::Long::Configure($old_go_conf);
         unless ($res) {
@@ -1113,7 +1113,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-12-11.
+This document describes version 0.80 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-12-15.
 
 =head1 SYNOPSIS
 
@@ -1421,7 +1421,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-GetArgs-Argv>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-GetArgs-Argv>.
 
 =head1 BUGS
 
